Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Betty Documentation

Betty visualizes and publishes your family history by building interactive, encyclopedia-like genealogy websites out of your Gramps and GEDCOM family trees.

## Features

Betty generates generates a static site from your genealogy records. This means that once your site has been generated, you will not need any special software to publish it. It’s fast and secure.

- Builds pages for people, places, events, and media

- Renders interactive maps and family trees

- Privacy by default

- Fully multilingual: localize the site to one or more languages of your choice

- Responsive, and mobile- and touch-friendly interface

View an example